clear_cache

data.clear_cache()

Remove the local cache of downloaded case-study files.

Deletes the pooch cache directory used by the loaders (the OS cache directory for geometrics, or the directory named by the GEOMETRICS_DATA_DIR environment variable). The next loader call downloads the files again.